@@ -98,7 +98,7 @@ def add_show_list_common_argument(parser):
         '-D', '--show-details',
         help=_('Show detailed info'),
         action='store_true',
-        default=False, )
+        default=False,)
     parser.add_argument(
         '--show_details',
         action='store_true',
@@ -279,12 +279,12 @@ def parse_args_to_dict(values_specs):
 
     # populate the parser with arguments
     _parser = argparse.ArgumentParser(add_help=False)
-    for opt, optspec in six.iteritems(_options):
+    for opt, optspec in _options.items():
         _parser.add_argument(opt, **optspec)
     _args = _parser.parse_args(_values_specs)
 
     result_dict = {}
-    for opt in _options.iterkeys():
+    for opt in _options.keys():
         _opt = opt.split('--', 2)[1]
         _opt = _opt.replace('-', '_')
         _value = getattr(_args, _opt)
@@ -303,7 +303,7 @@ def _merge_args(qCmd, parsed_args, _extra_values, value_specs):
     @param values_specs: the unparsed unknown parts
     """
     temp_values = _extra_values.copy()
-    for key, value in six.iteritems(temp_values):
+    for key, value in temp_values.items():
         if hasattr(parsed_args, key):
             arg_value = getattr(parsed_args, key)
             if arg_value is not None and value is not None:
@@ -387,7 +387,7 @@ class TackerCommand(command.OpenStackCommand):
     def format_output_data(self, data):
         # Modify data to make it more readable
         if self.resource in data:
-            for k, v in six.iteritems(data[self.resource]):
+            for k, v in data[self.resource].items():
                 if isinstance(v, list):
                     value = '\n'.join(jsonutils.dumps(
                         i, indent=self.json_indent) if isinstance(i, dict)
@@ -450,7 +450,7 @@ class CreateCommand(TackerCommand, show.ShowOne):
                     info.pop(f)
         else:
             info = {'': ''}
-        return zip(*sorted(six.iteritems(info)))
+        return zip(*sorted(info.items()))
 
 
 class UpdateCommand(TackerCommand):
@@ -500,7 +500,7 @@ class UpdateCommand(TackerCommand):
 
 
 class DeleteCommand(TackerCommand):
-    """Delete a given resource
+    """Delete given resource(s)
 
     """
 
@@ -508,34 +508,67 @@ class DeleteCommand(TackerCommand):
     resource = None
     log = None
     allow_names = True
+    deleted_msg = {}
 
     def get_parser(self, prog_name):
         parser = super(DeleteCommand, self).get_parser(prog_name)
         if self.allow_names:
-            help_str = _('ID or name of %s to delete')
+            help_str = _('IDs or names of %s to delete')
         else:
-            help_str = _('ID of %s to delete')
+            help_str = _('IDs of %s to delete')
         parser.add_argument(
-            'id', metavar=self.resource.upper(),
+            'ids', nargs='+',
+            metavar=self.resource.upper(),
             help=help_str % self.resource)
+        self.add_known_arguments(parser)
         return parser
 
     def run(self, parsed_args):
-        self.log.debug('run(%s)', parsed_args)
+        failure = False
+        deleted_ids = []
+        failed_items = {}
         tacker_client = self.get_client()
         tacker_client.format = parsed_args.request_format
         obj_deleter = getattr(tacker_client,
                               "delete_%s" % self.resource)
-        if self.allow_names:
-            _id = find_resourceid_by_name_or_id(tacker_client, self.resource,
-                                                parsed_args.id)
+        body = self.args2body(parsed_args)
+
+        for resource_id in parsed_args.ids:
+            try:
+                if self.allow_names:
+                    _id = find_resourceid_by_name_or_id(
+                        tacker_client, self.resource, resource_id)
+                else:
+                    _id = resource_id
+                if body:
+                    obj_deleter(_id, body)
+                else:
+                    obj_deleter(_id)
+                deleted_ids.append(resource_id)
+            except Exception as e:
+                failure = True
+                failed_items[resource_id] = e
+        if failure:
+            msg = ''
+            if deleted_ids:
+                status_msg = self.deleted_msg.get(self.resource, 'deleted')
+                msg = (_('Successfully %(status_msg)s %(resource)s(s):'
+                         ' %(deleted_list)s') % {'status_msg': status_msg,
+                                                 'deleted_list':
+                                                 ', '.join(deleted_ids),
+                                                 'resource': self.resource})
+            err_msg = _("\n\nUnable to delete the below"
+                        " %s(s):") % self.resource
+            for failed_id, error in failed_items.iteritems():
+                err_msg += (_('\n Cannot delete %(failed_id)s: %(error)s')
+                            % {'failed_id': failed_id,
+                               'error': error})
+            msg += err_msg
+            raise exceptions.CommandError(msg)
         else:
-            _id = parsed_args.id
-        obj_deleter(_id)
-        print((_('Deleted %(resource)s: %(id)s')
-               % {'id': parsed_args.id,
-                  'resource': self.resource}),
-              file=self.app.stdout)
+            print((_('All specified %(resource)s(s) %(msg)s successfully')
+                   % {'msg': self.deleted_msg.get(self.resource, 'deleted'),
+                      'resource': self.resource}))
         return
 
 
@@ -685,6 +718,6 @@ class ShowCommand(TackerCommand, show.ShowOne):
         self.format_output_data(data)
         resource = data[self.resource]
         if self.resource in data:
-            return zip(*sorted(six.iteritems(resource)))
+            return zip(*sorted(resource.items()))
         else:
             return None
